@@ -2,7 +2,7 @@ package Google::Adwords::AdService;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('0.3');
+use version; our $VERSION = qv('0.4');
 
 use base 'Google::Adwords::Service';
 
@@ -274,7 +274,6 @@ sub getAd
 #           adIds       => [ 3982, 2787, 17872 ],
 #           startDay    => $startDay,
 #           endDay      => $endDay,
-#           inPST       => 1,
 #   });
 # Purpose    : Get stats on a set of Ads
 # Returns    :  A list of StatsRecord object for each Ad
@@ -283,8 +282,6 @@ sub getAd
 #       creativeIds  : array reference of Ad Ids
 #       startDay : starting day of the stats YYYY-MM-DD
 #       endDay : end day of the stats YYYY-MM-DD
-#       inPST : True = get stats in America/Los_Angeles timezone
-#           (Google headquarters) regardless of the parent account's localtimezone.
 # Throws     : no exceptions
 # Comments   : none
 # See Also   : n/a
@@ -300,7 +297,6 @@ sub getAdStats
     my $ra_id    = $args_ref->{adIds}    || [];
     my $startDay = $args_ref->{startDay} || '';
     my $endDay   = $args_ref->{endDay}   || '';
-    my $inPST    = $args_ref->{inPST}    || 0;
 
     my @params;
     push @params,
@@ -308,7 +304,6 @@ sub getAdStats
     push @params, SOAP::Data->name( 'adIds'    => @{$ra_id} )->type('');
     push @params, SOAP::Data->name( 'startDay' => $startDay )->type('');
     push @params, SOAP::Data->name( 'endDay'   => $endDay )->type('');
-    push @params, SOAP::Data->name( 'inPST'    => $inPST )->type('');
 
     my $result = $self->_create_service_and_call(
         {
@@ -465,7 +460,7 @@ Google::Adwords::AdService - Interact with the Google Adwords AdService API call
  
 =head1 VERSION
  
-This documentation refers to Google::Adwords::AdService version 0.3
+This documentation refers to Google::Adwords::AdService version 0.4
  
  
 =head1 SYNOPSIS
@@ -682,7 +677,6 @@ Get statistics for a list of ads in an ad group.
         adIds       => [ 3982, 2787, 17872 ],
         startDay    => $startDay,
         endDay      => $endDay,
-        inPST       => 1,
     });
 
 =head3 Parameters
@@ -701,8 +695,6 @@ be collected in format YYYY-MM-DD
 * endDay => The ending day of the period for which statistics are to be
 collected in format YYYY-MM-DD
 
-* inPST => Set to 1 to get stats in America/Los_Angeles timezone (Google
-headquarters) regardless of the parent account's localtimezone.
 
 =back
 
