@@ -1,5 +1,6 @@
 package Google::Adwords::Business;
-use strict; use warnings;
+use strict;
+use warnings;
 
 use version; our $VERSION = qv('0.0.1');
 
@@ -17,7 +18,7 @@ my @fields = qw/
     postalCode
     region
     timestamp
-/;
+    /;
 
 __PACKAGE__->mk_accessors(@fields);
 
@@ -116,7 +117,7 @@ B<Accessors>
 Rohan Almeida <rohan@almeida.in>
  
  
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
 Copyright (c) 2006 Rohan Almeida <rohan@almeida.in>. All rights
 reserved.
