@@ -199,7 +199,8 @@ sub scheduleReportJob
             ->type('');
     }
     if ( defined $job->clientEmails ) {
-        my @p = ( ref( $job->clientEmails ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->clientEmails ) eq 'ARRAY' )
             ? @{ $job->clientEmails }
             : $job->clientEmails;
         push @job_params, SOAP::Data->name( 'clientEmails' => @p )->type('');
@@ -223,58 +224,67 @@ sub scheduleReportJob
             SOAP::Data->name( 'startDay' => $job->startDay )->type('');
     }
     if ( defined $job->adWordsType ) {
-        my @p = ( ref( $job->adWordsType ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->adWordsType ) eq 'ARRAY' )
             ? @{ $job->adWordsType }
             : $job->adWordsType;
         push @job_params, SOAP::Data->name( 'adWordsType' => @p )->type('');
     }
     if ( defined $job->campaigns ) {
-        my @p = ( ref( $job->campaigns ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->campaigns ) eq 'ARRAY' )
             ? @{ $job->campaigns }
             : $job->campaigns;
         push @job_params, SOAP::Data->name( 'campaigns' => @p )->type('');
     }
     if ( defined $job->campaignStatuses ) {
-        my @p = ( ref( $job->campaignStatuses ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->campaignStatuses ) eq 'ARRAY' )
             ? @{ $job->campaignStatuses }
             : $job->campaignStatuses;
         push @job_params,
             SOAP::Data->name( 'campaignStatuses' => @p )->type('');
     }
     if ( defined $job->adGroups ) {
-        my @p = ( ref( $job->adGroup ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->adGroup ) eq 'ARRAY' )
             ? @{ $job->adGroup }
             : $job->adGroup;
         push @job_params, SOAP::Data->name( 'adGroups' => @p )->type('');
     }
     if ( defined $job->adGroupStatuses ) {
-        my @p = ( ref( $job->adGroupStatuses ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->adGroupStatuses ) eq 'ARRAY' )
             ? @{ $job->adGroupStatuses }
             : $job->adGroupStatuses;
         push @job_params,
             SOAP::Data->name( 'adGroupStatuses' => @p )->type('');
     }
     if ( defined $job->keywords ) {
-        my @p = ( ref( $job->keywords ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->keywords ) eq 'ARRAY' )
             ? @{ $job->keywords }
             : $job->keywords;
         push @job_params, SOAP::Data->name( 'keywords' => @p )->type('');
     }
     if ( defined $job->keywordStatuses ) {
-        my @p = ( ref( $job->keywordStatuses ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->keywordStatuses ) eq 'ARRAY' )
             ? @{ $job->keywordStatuses }
             : $job->keywordStatuses;
         push @job_params,
             SOAP::Data->name( 'keywordStatuses' => @p )->type('');
     }
     if ( defined $job->keywordType ) {
-        my @p = ( ref( $job->keywordType ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->keywordType ) eq 'ARRAY' )
             ? @{ $job->keywordType }
             : $job->keywordType;
         push @job_params, SOAP::Data->name( 'keywordType' => @p )->type('');
     }
     if ( defined $job->customOptions ) {
-        my @p = ( ref( $job->customOptions ) eq 'ARRAY' )
+        my @p =
+            ( ref( $job->customOptions ) eq 'ARRAY' )
             ? @{ $job->customOptions }
             : $job->customOptions;
         push @job_params, SOAP::Data->name( 'customOptions' => @p )->type('');
