@@ -1,5 +1,6 @@
 package Google::Adwords::SeedKeyword;
-use strict; use warnings;
+use strict;
+use warnings;
 
 use version; our $VERSION = qv('0.0.1');
 
@@ -9,7 +10,7 @@ my @fields = qw/
     negative
     text
     type
-/;
+    /;
 
 __PACKAGE__->mk_accessors(@fields);
 
@@ -56,7 +57,7 @@ Rohan Almeida <rohan@almeida.in>
 
  
  
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
 Copyright (c) 2006 Rohan Almeida <rohan@almeida.in>. All rights
 reserved.
